# The following has been generated automatically from src/core/mesh/qgsmeshlayertemporalproperties.h
try:
    QgsMeshLayerTemporalProperties.__overridden_methods__ = ['writeXml', 'readXml', 'setDefaultsFromDataProviderTemporalCapabilities']
    QgsMeshLayerTemporalProperties.__group__ = ['mesh']
except (NameError, AttributeError):
    pass
