# The following has been generated automatically from src/core/editform/qgsattributeeditortextelement.h
try:
    QgsAttributeEditorTextElement.__overridden_methods__ = ['clone']
    QgsAttributeEditorTextElement.__group__ = ['editform']
except (NameError, AttributeError):
    pass
